@@ -127,7 +127,7 @@ gnome_font_selection_class_init (GnomeFontSelectionClass *klass)
 	object_class = (GObjectClass *) klass;
 	gtk_object_class = (GtkObjectClass *) klass;
   
-	gfs_parent_class = gtk_type_class (GTK_TYPE_HBOX);
+	gfs_parent_class = g_type_class_peek (GTK_TYPE_HBOX);
   
 	gfs_signals[FONT_SET] = g_signal_new ("font_set",
 					      G_OBJECT_CLASS_TYPE (object_class),
@@ -189,7 +189,7 @@ gnome_font_selection_init (GnomeFontSelection * fontsel)
 	gtk_tree_view_append_column (GTK_TREE_VIEW (tv), col);
 	gtk_widget_show (tv);
 	g_signal_connect ((GObject*) selection, "changed",
-			  GTK_SIGNAL_FUNC (gnome_font_selection_select_family),
+			  G_CALLBACK (gnome_font_selection_select_family),
 			  fontsel);
 	gtk_container_add ((GtkContainer *) sw, tv);
 	fontsel->family = tv;
@@ -240,7 +240,7 @@ gnome_font_selection_init (GnomeFontSelection * fontsel)
 	gtk_tree_view_append_column (GTK_TREE_VIEW (tv), col);
 	gtk_widget_show (tv);
 	g_signal_connect ((GObject*) selection, "changed",
-			  GTK_SIGNAL_FUNC (gnome_font_selection_select_style),
+			  G_CALLBACK (gnome_font_selection_select_style),
 			  fontsel);
 	gtk_container_add ((GtkContainer *) sw, tv);
 	fontsel->style = tv;
@@ -650,7 +650,7 @@ gnome_font_preview_class_init (GnomeFontPreviewClass *klass)
   
 	object_class = (GtkObjectClass *) klass;
   
-	gfp_parent_class = gtk_type_class (GTK_TYPE_IMAGE);
+	gfp_parent_class = g_type_class_peek (GTK_TYPE_IMAGE);
   
 	object_class->destroy = gnome_font_preview_destroy;
 }
@@ -850,7 +850,7 @@ gnome_font_dialog_class_init (GnomeFontDialogClass *klass)
   
 	object_class = (GtkObjectClass*) klass;
   
-	gfsd_parent_class = gtk_type_class (GTK_TYPE_DIALOG);
+	gfsd_parent_class = g_type_class_peek (GTK_TYPE_DIALOG);
 }
 
 static void
