@@ -25,6 +25,8 @@
  *
  */
 
+#undef GTK_DISABLE_DEPRECATED
+
 #include <config.h>
 
 #include <math.h>
@@ -34,7 +36,6 @@
 #include <gdk/gdkkeysyms.h>
 
 #include <gtk/gtk.h>
-#include <gtk/gtkaction.h>
 
 #include <libgnomeprint/private/gnome-print-private.h>
 #include <libgnomeprint/gnome-print-meta.h>
