@@ -31,7 +31,7 @@
 G_BEGIN_DECLS
 
 #include <libgnomeprint/gnome-print-config.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
 typedef enum {
 	   GNOME_PRINT_WIDGET_CHECKBUTTON
