@@ -60,7 +60,7 @@ struct _GnomePrinterSelectorClass {
 };
 
 
-GtkType            gnome_printer_selector_get_type (void);
+GType              gnome_printer_selector_get_type (void);
 GtkWidget *        gnome_printer_selector_new (GnomePrintConfig *config);
 GtkWidget *        gnome_printer_selector_new_default (void);
 GnomePrintConfig * gnome_printer_selector_get_config (GnomePrinterSelector *psel);
